﻿//
// Copyright (c) 2017, MindFusion LLC - Bulgaria.
//

using System;
using System.Collections.ObjectModel;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using MindFusion.Charting;
using MindFusion.Charting.Components;
using MindFusion.Charting.WebForms;

using System.Drawing;
using Brush = MindFusion.Drawing.Brush;
using SolidBrush = MindFusion.Drawing.SolidBrush;
using LinearGradientBrush = MindFusion.Drawing.LinearGradientBrush;

namespace Test
{
	public partial class MultipleAxes : System.Web.UI.Page
	{
		protected void Page_Load(object sender, EventArgs e)
		{
			if (!IsPostBack)
			{
				var plot = new Plot2D();

				// sample temperature data for bar graphics
				var barSeries = new Series2D(
								new List<double>() { 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 },//x
								new List<double>() { -3, -7, 10, 12, 20, 29, 33, 30, 24, 15, 2, -8 },//y
								new List<string>() { "January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December" });

				barSeries.Title = "Temperature";
				barSeries.SupportedLabels = LabelKinds.XAxisLabel;

				// sample pressure data for line graphics
				var lineSeries = new Series2D(
								new List<double>() { 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 },//x
								new List<double>() { 100120, 101044, 101503, 103499, 102122, 100593, 95542, 102223, 103002, 102994, 102843, 101332 },//right-y
								null);
				lineSeries.Title = "Pressure";

				// draw bars
				var barRenderer = new BarRenderer(new ObservableCollection<Series>() { barSeries });
				barRenderer.SeriesStyle = new UniformSeriesStyle(new SolidBrush(ColorTranslator.FromHtml("#9caac6")),
					new SolidBrush(ColorTranslator.FromHtml("#616a7f")), 2, System.Drawing.Drawing2D.DashStyle.Solid);

				// draw lines
				var lineRenderer = new LineRenderer(
								new ObservableCollection<Series>() { lineSeries });
				lineRenderer.SeriesStyle = new UniformSeriesStyle(new SolidBrush(ColorTranslator.FromHtml("#ce0000")),
					new SolidBrush(ColorTranslator.FromHtml("#ce0000")), 4, System.Drawing.Drawing2D.DashStyle.Solid);

				// add graphics to plot
				plot.SeriesRenderers.Add(barRenderer);
				plot.SeriesRenderers.Add(lineRenderer);

				// draw annotations
				var annotations = new Series2D(
								new List<double>() { 7 }, //x
								new List<double>() { 95542 },//right-y
								new List<string>() { "TORNADO" });
				var annotationRenderer = new AnnotationRenderer(new ObservableCollection<Series>() { annotations });
				plot.SeriesRenderers.Add(annotationRenderer);

				// create axes
				var celsiusAxis = new Axis();
				celsiusAxis.Interval = 5;
				celsiusAxis.MinValue = -20;
				celsiusAxis.MaxValue = 50;
				celsiusAxis.Title = "Celsius";

				var fahrenheitAxis = new Axis();
				fahrenheitAxis.MinValue = -20 * 1.8 + 32;
				fahrenheitAxis.MaxValue = 50 * 1.8 + 32;
				fahrenheitAxis.Interval = 10;
				fahrenheitAxis.Title = "Fahrenheit";

				var kelvinAxis = new Axis();
				kelvinAxis.MinValue = -20 + 273.15;
				kelvinAxis.MaxValue = 50 + 273.15;
				kelvinAxis.Interval = 5;
				kelvinAxis.Title = "Kelvin";

				var monthAxis = new Axis();
				monthAxis.Interval = 1;
				monthAxis.MinValue = 0;
				monthAxis.MaxValue = 12;
				monthAxis.Title = "Months";

				var pascals = new Axis();
				pascals.MinValue = 90000;
				pascals.MaxValue = 106000;
				pascals.Interval = 1000;
				pascals.Title = "Pressure";

				plot.YAxis = celsiusAxis;
				plot.XAxis = monthAxis;
				lineRenderer.YAxis = annotationRenderer.YAxis = pascals;

				// add legend
				var legendRenderer = new LegendRenderer();
				legendRenderer.Content = new ObservableCollection<SeriesRenderer>() { barRenderer, lineRenderer };
				legendRenderer.Background = new SolidBrush(ColorTranslator.FromHtml("#e0e9e9"));
				dashboard.RootPanel.Children.Add(legendRenderer);

				// create dashboard layout
				var xAxisRenderer = new XAxisRenderer(monthAxis);
				xAxisRenderer.LabelsSource = plot;

				dashboard.LayoutBuilder.CreateAndAddPlotAndAxes(
								plot, null,
								 new YAxisRenderer[] {new YAxisRenderer(celsiusAxis),
					new YAxisRenderer(fahrenheitAxis),
					new YAxisRenderer(kelvinAxis)},
								new XAxisRenderer[] { xAxisRenderer },
								new YAxisRenderer[] { new YAxisRenderer(pascals) });
			}
		}

		protected void Button1_Click(object sender, EventArgs e)
		{

		}
	}
}